@@ -85,6 +85,8 @@ class UWC_Cache {
       } elseif (uwc_contextutils_is_image_preview_path($this->path) ||
 		uwc_contextutils_is_image_full_path($this->path)) {
 	$this->cache_action="imagecache";
+      } elseif (uwc_contextutils_is_gallery_path($this->path)) {
+	$this->cache_action="xulcache";
       } elseif (uwc_contextutils_is_uwikicms_path($this->path)) {
 	$this->cache_action="nocache";
       } else {
@@ -114,6 +116,7 @@ class UWC_Cache {
     switch ($this->cache_action) {
     case "cache":
     case "imagecache":
+    case "xulcache":
       /*
        * It's important go get here without including page.php
        * since it's not really needed and can only improve performances.
@@ -144,6 +147,9 @@ class UWC_Cache {
       if ($this->http_code==200 && $this->is_image()) {
 	header('Content-Type: image/jpeg');
       }
+      if ($this->http_code==200 && $this->is_xul()) {
+	header('Content-Type: application/vnd.mozilla.xul+xml');
+      }
       echo file_get_contents($this->file);
     } else {
       require("page.php");
@@ -162,8 +168,12 @@ class UWC_Cache {
     return $this->cache_action=="imagecache";
   }
 
+  function is_xul() {
+    return $this->cache_action=="xulcache";
+  }
+
   function update_file($http_code) {
-    if ($this->is_image()) {
+    if ($this->is_image() || $this->is_xul()) {
       $this->file=sprintf("%s/_uwikicms/cache/%s%s",
 			  $this->conf->prefix,
 			  $http_code,
