@@ -66,7 +66,8 @@ $this->messages=array
    "rights_3"=>"Document confidentiel.",
    "meta_description"=>"%s (pas de description d&eacute;taill&eacute;e)",
    "meta_copyright"=>"Copyleft &copy; %s %s",
-   "page_generated_by_uwikicms"=>"Page g&eacute;n&eacute;r&eacute;e par <a href=\"http://www.ufoot.org/uwikicms\">UWiKiCMS</a> (v%s) le %s.",
+   "page_generated_by_uwikicms"=>"Page g&eacute;n&eacute;r&eacute;e par <a href=\"http://www.ufoot.org/uwikicms\">UWiKiCMS</a> %s le %s.",
+   "xul_generated_by_uwikicms"=>"Interface XUL g&eacute;n&eacute;r&eacute;e par UWiKiCMS %s le %s.",
    "last_update"=>"Mis &agrave; jour le %s.",
    "source"=>"Source&nbsp;:",
    "action_root"=>"Accueil",
@@ -81,8 +82,6 @@ $this->messages=array
    "action_clearcache"=>"Vider le cache",
    "action_allinone"=>"Tout sur une page",
    "action_gallery"=>"Diaporama (Mozilla/Firefox)",
-   "login_success"=>"Connect&eacute; en tant que %s.",
-   "login_failed"=>"La connexion a &eacute;chou&eacute;.",
    "login_user"=>"Identifiant",
    "login_password"=>"Mot de passe",
    "login_connect"=>"Se connecter",
