@@ -133,7 +133,6 @@ class UWC_Page {
       case "403":
       case "404":
       case "loginform":
-      case "login":
       case "logout":
       case "createform":
       case "imagecreateform":
@@ -508,7 +507,7 @@ class UWC_Page {
   }
 
   function get_loginform_url() {
-    return $this->make_url("/_uwikicms/loginform.php",array("continue"=>$this->get_path()));
+    return $this->make_url($this->get_path(),array("action"=>"loginform"));
   }
 
   function get_login_url() {
@@ -516,7 +515,7 @@ class UWC_Page {
   }
 
   function get_logout_url() {
-    return $this->make_url("/_uwikicms/logout.php",array("continue"=>$this->get_path(),"session"=>""));
+    return $this->make_url($this->get_path(),array("action"=>"logout","continue"=>$this->get_path(),"session"=>""));
   }
 
   function get_continue_url() {
@@ -528,11 +527,11 @@ class UWC_Page {
   }
 
   function get_clearcacheform_url() {
-    return $this->make_url("",array("action"=>"clearcacheform"));
+    return $this->make_url($this->get_path(),array("action"=>"clearcacheform"));
   }
 
   function get_clearcache_url() {
-    return $this->make_url("/_uwikicms/clearcache.php");
+    return $this->make_url("/_uwikicms/clearcache.php",array("continue"=>$this->get_path()));
   }
 
   function get_allinoneform_url() {
@@ -583,6 +582,14 @@ class UWC_Page {
     return $this->content->get_full_h();
   }
 
+  function get_image_fullscaled_w() {
+    return $this->content->get_fullscaled_w();
+  }
+
+  function get_image_fullscaled_h() {
+    return $this->content->get_fullscaled_h();
+  }
+
   function get_gallery_url() {
     $path=(preg_match("/image/",$this->context->action)) ? $this->get_up_path() : $this->get_path();
     return $this->make_url($path."/gallery.xul");
@@ -790,7 +797,7 @@ class UWC_Page {
   }
 
   function translate_xul($msg_id) {
-    return htmlspecialchars(html_entity_decode($this->translate($msg_id)));
+    return uwc_format_html_to_xul($this->translate($msg_id));
   }
 
   function translate1($msg_id,$par1) {
@@ -1067,7 +1074,6 @@ class UWC_Page {
       case "403":
       case "404":
       case "loginform":
-      case "login":
       case "logout":
       case "view":
       case "external":
